@@ -52,6 +52,10 @@ use Net::Silk qw( :basic );
 use Net::Silk::IPAddr;
 use Net::Silk::IPWildcard;
 
+use Math::Int128 qw( uint128 );
+use Math::Int128::die_on_overflow;
+use Math::BigInt;
+
 use Symbol();
 
 use overload (
@@ -122,6 +126,36 @@ sub copy {
   $new;
 }
 
+sub cardinality {
+  my $self = shift;
+  my $card;
+  eval { $card = $self->_cardinality };
+  if ($@) {
+    if ($@ =~ /overflow/) {
+      # >= UINT64_MAX
+      my $thing = $self->_cardinality_as_str;
+      eval { $card = uint128($self->_cardinality_as_str) };
+      if ($@) {
+        if ($@ =~ /overflow/) {
+          # UINT128_MAX...except the first call returns 0 which isn't
+          # what it's supposed to do, so we catch it below
+          $card = Math::BigInt->new($self->_cardinality_as_str);
+        }
+        else {
+          croak $@;
+        }
+      }
+    }
+    else {
+      croak $@;
+    }
+  }
+  elsif ($card == 0 && $self->iter->()) {
+    $card = Math::BigInt->new("0x100000000000000000000000000000000");
+  }
+  $card;
+}
+
 sub add {
   my $self = shift;
   return unless @_;
@@ -191,11 +225,10 @@ sub remove {
   my @items;
   foreach (map { _parse_item($_) } @_) {
     if (UNIVERSAL::isa($_, SILK_IPADDR_CLASS)) {
-      eval { Net::Silk::IPSet::remove_addr($self, $_) };
+      Net::Silk::IPSet::remove_addr($self, $_);
     }
     elsif (UNIVERSAL::isa($_, SILK_IPWILDCARD_CLASS)) {
-      eval { Net::Silk::IPSet::remove_wildcard($self, $_) };
-
+      Net::Silk::IPSet::remove_wildcard($self, $_);
     }
     elsif (UNIVERSAL::isa($_, SILK_IPSET_CLASS)) {
       Net::Silk::IPSet::_difference_update($self, $_);
@@ -238,10 +271,10 @@ sub difference_update {
       Net::Silk::IPSet::_difference_update($self, $_);
     }
     elsif (UNIVERSAL::isa($_, SILK_IPADDR_CLASS)) {
-      eval { Net::Silk::IPSet::remove_addr($self, $_) };
+      Net::Silk::IPSet::remove_addr($self, $_);
     }
     elsif (UNIVERSAL::isa($_, SILK_IPWILDCARD_CLASS)) {
-      eval { Net::Silk::IPSet::remove_wildcard($self, $_) };
+      Net::Silk::IPSet::remove_wildcard($self, $_);
     }
     else {
       $_ = SILK_IPSET_CLASS->new($_);
@@ -301,6 +334,8 @@ sub iter {
   my $cidr = shift || 0;
   my $iter = Net::Silk::IPSet::iter_xs->bind($self, $cidr);
   if ($cidr) {
+    # workaround for libsilk wildcard bug
+    return sub { } unless $self->cardinality;
     return sub {
       if (wantarray) {
         my @items;
